@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "marquee-header" "0.1.0"
+(define-package "marquee-header" "20260101.601"
   "Code interface for displaying marquee in header."
   '((emacs "26.1"))
   :url "https://github.com/jcs-elpa/marquee-header"
-  :commit "1fee5bbec486d0755954f5cafda67f342dc7daa1"
-  :revdesc "1fee5bbec486"
+  :commit "c0e884eea86ef818a652dba9a1719b50489813a6"
+  :revdesc "c0e884eea86e"
   :keywords '("wp" "animation" "marquee")
   :authors '(("Jen-Chieh" . "jcs090218@gmail.com"))
   :maintainers '(("Jen-Chieh" . "jcs090218@gmail.com")))
